# JupySQL
![CI](https://github.com/ploomber/jupysql/workflows/CI/badge.svg)
![CI Integration Tests](https://github.com/ploomber/jupysql/workflows/CI%20-%20DB%20Integration/badge.svg)
![Broken Links](https://github.com/ploomber/jupysql/workflows/check-for-broken-links/badge.svg)
[![PyPI version](https://badge.fury.io/py/jupysql.svg)](https://badge.fury.io/py/jupysql)
[![Twitter](https://img.shields.io/twitter/follow/edublancas?label=Follow&style=social)](https://twitter.com/intent/user?screen_name=ploomber)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Downloads](https://static.pepy.tech/badge/jupysql/month)](https://pepy.tech/project/jupysql)

<p align="center">
  <a href="https://ploomber.io/community">Join our community</a>
  |
  <a href="https://share.hsforms.com/1E7Qa_OpcRPi_MV-segFsaAe6c2g">Newsletter</a>
  |
  <a href="mailto:contact@ploomber.io">Contact us</a>
  |
  <a href="https://jupysql.ploomber.io/">Docs</a>
  |
  <a href="https://ploomber.io/blog">Blog</a>
  |
  <a href="https://ploomber.io">Website</a>
  |
  <a href="https://www.youtube.com/channel/UCaIS5BMlmeNQE4-Gn0xTDXQ">YouTube</a>
</p>

Run SQL in Jupyter/IPython via a `%sql` and `%%sql` magics.

<p align="center">
  <a href="https://binder.ploomber.io/v2/gh/ploomber/jupysql/master?urlpath=lab/tree/doc/quick-start.md"> <img src="_static/get-started.svg" alt="Get Started"> </a>
</p>

## Features

- [Pandas integration](https://jupysql.ploomber.io/en/latest/integrations/pandas.html)
- [SQL composition (no more hard-to-debug CTEs!)](https://jupysql.ploomber.io/en/latest/compose.html)
- [Plot massive datasets without blowing up memory](https://jupysql.ploomber.io/en/latest/plot.html)
- [DuckDB integration](https://jupysql.ploomber.io/en/latest/integrations/duckdb.html)

## Installation

```
pip install jupysql
```

or:

```
conda install jupysql -c conda-forge
```

## Documentation

[Click here to see the documentation.](https://jupysql.ploomber.io)


## Credits

This project is a fork of [ipython-sql](https://github.com/catherinedevlin/ipython-sql); the objective is to turn this project into a full-featured SQL client for Jupyter. We're looking for feedback and taking feature requests, so please [join our community](https://ploomber.io/community) and enter the #jupysql channel.
